function expandTable(newsitems,batch) {
    var table = document.getElementById("newstable");
    for (var k=newsitems;k<Math.min(newsitems+batch,news.length);k++) {
        var row = table.insertRow(k);
        var cell1 = row.insertCell(0);
        var cell2 = row.insertCell(1);
        cell1.style = "font-weight: bold; text-align: left;";
        cell1.innerHTML = news[k][0];
        cell2.innerHTML = news[k][1];
    }
}

var news = [ // date, text

  ["September 30, 2025",
   "SLEPc 3.24 has been released. The distribution file is available at the <a href='https://slepc.upv.es/release/installation/download.html'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["September 8, 2025",
   "New patch release: slepc-3.23.3 includes miscellaneous fixes."],

  ["July 29, 2025",
   "We are in the process of renovating the SLEPc website. The new website will be published during the first weeks of September, and it will look more like the PETSc website, with a similar organization."],

  ["June 30, 2025",
   "New patch release: slepc-3.23.2 includes miscellaneous fixes for configure/build and also for some solvers such as two-sided EPS."],

  ["May 1, 2025",
   "New patch release: slepc-3.23.1 includes minor fixes in Fortran bindings, as well as for configuration issues and compile warnings."],

  ["Mar 29, 2025",
   "SLEPc 3.23 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Dec 2, 2024",
   "New patch release: slepc-3.22.2 includes several build-related fixes, mainly for slepc4py, and minor fixes in BSE solvers."],

  ["Oct 28, 2024",
   "New patch release: slepc-3.22.1 fixes some issues related to makefiles, and other minor problems."],

  ["Sep 29, 2024",
   "SLEPc 3.22 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Sep 25, 2024",
   "New patch release: slepc-3.21.2 contains miscellaneous fixes, including compilation in some systems."],

  ["Apr 27, 2024",
   "New patch release: slepc-3.21.1 contains miscellaneous changes including CUDA-related performance fixes and fixes for installing slepc4py with pip."],

  ["Mar 30, 2024",
   "SLEPc 3.21 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Mar 19, 2024",
   "SLEPc developers will be attending the forthcoming <a href='http://cds.uni-koeln.de/en/workshops/petsc-2024/home' target=_blank>PETSc User Meeting 2024</a> in Cologne on May 23-24, 2024."],

  ["Mar 15, 2024",
   "New patch release: slepc-3.20.2 contains miscellaneous fixes."],

  ["Nov 27, 2023",
   "New patch release: slepc-3.20.1 contains miscellaneous fixes."],

  ["Sep 29, 2023",
   "SLEPc 3.20 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Sep 5, 2023",
   "New patch release: slepc-3.19.2 contains miscellaneous fixes, including build fixes for fortran and python."],

  ["May 15, 2023",
   "New patch release: slepc-3.19.1 contains miscellaneous fixes, mainly in makefiles."],

  ["Mar 31, 2023",
   "SLEPc 3.19 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Mar 24, 2023",
   "New patch release: slepc-3.18.3 fixes compilation with GNUMake 4.4.1 and also fixes some issues when configuring with external packages."],

  ["Jan 26, 2023",
   "New patch release: slepc-3.18.2 fixes a configure problem, and some python issues."],

  ["Nov 2, 2022",
   "New patch release: slepc-3.18.1 contains miscellaneous fixes."],

  ["Oct 1, 2022",
   "SLEPc 3.18 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Aug 9, 2022",
   "New patch release: slepc-3.17.2 contains miscellaneous fixes, most of them related to Fortran."],

  ["Apr 11, 2022",
   "New patch releases: slepc-3.16.3 and slepc-3.17.1 both contain a fix that recover installation via pip install, which was broken in versions 3.16.2 and 3.17.0."],

  ["Mar 31, 2022",
   "SLEPc 3.17 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Feb 1, 2022",
   "New patch release: slepc-3.16.2 contains miscellaneous fixes."],

  ["Nov 17, 2021",
   "New patch release: slepc-3.16.1 contains miscellaneous fixes, most notably related to the NEP module."],

  ["Sep 30, 2021",
   "SLEPc 3.16 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Sep 20, 2021",
   "New patch release: slepc-3.15.2 fixes a problem with polynomial filters and other minor issues."],

  ["May 28, 2021",
   "New patch release: slepc-3.15.1 contains various configuration and compilation fixes, and bug fixes in SVDCROSS and SVDCYCLIC."],

  ["Mar 31, 2021",
   "SLEPc 3.15 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],

  ["Feb 27, 2021",
   "The development version has changed the branch name, as in PETSc: 'main' instead of 'master'. Users of the git repository should switch to the 'main' branch with 'git fetch && git checkout main && git branch -D master'"],

  ["Feb 1, 2021",
   "New patch release: slepc-3.14.2 contains miscellaneous fixes, mainly in the configure script, and also in the interface to ScaLAPACK."],

  ["Dec 8, 2020",
   "New patch release: slepc-3.14.1 has miscellaneous fixes, including some fixes related to STFILTER and the wrapper to ELPA."],

  ["Sep 30, 2020",
   "SLEPc 3.14 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this version."],

  ["Sep 2, 2020",
   "New patch release: slepc-3.13.4 contains several fixes, and also the change to backward error convergence criterion by default in NEP."],

  ["Jun 14, 2020",
   "New patch release: slepc-3.13.3 has miscellaneous fixes, mostly related to configuring with python3."],

  ["May 12, 2020",
   "New patch release: slepc-3.13.2 mainly includes fixes in makefiles and configure scripts."],

  ["Apr 12, 2020",
   "New patch release: slepc-3.13.1 fixes compilation in some systems, and includes a few improvements in the new solver EPSLYAPII."],

  ["Mar 31, 2020",
   "SLEPc 3.13 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this version."],

  ["Jan 13, 2020",
   "New patch release: slepc-3.12.2 contains miscellaneous fixes."],

  ["Dec 10, 2019",
   "The SLEPc repository has been moved from BitBucket to GitLab. For each local copy of the SLEPc repository you need to do: <pre>git remote set-url origin git@gitlab.com:slepc/slepc.git </pre> or <pre>git remote set-url origin https://gitlab.com/slepc/slepc.git</pre>"],

  ["Nov 8, 2019",
   "New patch release: slepc-3.12.1 contains miscellaneous fixes."],

  ["Sep 30, 2019",
   "SLEPc 3.12 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. See a list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this version."],

  ["Jul 30, 2019",
   "New patch release: slepc-3.11.2 contains miscellaneous fixes."],

  ["Apr 30, 2019",
   "New patch release: slepc-3.11.1 contains miscellaneous fixes."],

  ["Mar 29, 2019",
   "SLEPc 3.11 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Feb 11, 2019",
   "New patch release: slepc-3.10.2 contains several compilation fixes, in particular for prefix installation."],

  ["Oct 23, 2018",
   "New patch release: slepc-3.10.1 contains a few fixes, particularly support for DESTDIR in prefix installation."],

  ["Sep 18, 2018",
   "SLEPc 3.10 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Jul 2, 2018",
   "New patch release: slepc-3.9.2 contains miscellaneous fixes."],

  ["May 2, 2018",
   "New patch release: slepc-3.9.1 contains several bug fixes, mainly related to the new PEP solver, and also fixes some minor problems when doing prefix installs."],

  ["Apr 12, 2018",
   "SLEPc 3.9 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Apr 3, 2018",
   "New patch release: slepc-3.8.3 fixes compilation problems in some machines."],

  ["Dec 1, 2017",
   "New patch release: slepc-3.8.2 contains several bug fixes, most notably in the evaluation of functions of complex Hermitian matrices."],

  ["Nov 3, 2017",
   "New patch release: slepc-3.8.1 contains fixes to the new filter functionality, among others."],

  ["Oct 20, 2017",
   "SLEPc 3.8 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Jun 6, 2017",
   "Several video-tutorials have been added to the <a href='https://slepc.upv.es/documentation'>documentation section</a>."],

  ["May 17, 2017",
   "New patch release: slepc-3.7.4 contains miscellaneous fixes."],

  ["Sep 29, 2016",
   "New patch release: slepc-3.7.3 fixes some bugs in auxiliary components of SLEPc such as DS, BV and RG."],

  ["Jul 19, 2016",
   "New patch release: slepc-3.7.2 contains miscellaneous fixes concerning different components of SLEPc."],

  ["May 27, 2016",
   "New patch release: slepc-3.7.1 contains miscellaneous fixes, mainly related to the MFNKRYLOV and PEPJD solvers."],

  ["May 16, 2016",
   "SLEPc 3.7 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Mar 29, 2016",
   "New patch release: slepc-3.6.3 contains miscellaneous fixes."],

  ["Mar 21, 2016",
   "A new SLEPc technical report STR-11 has been added in the <a href='https://slepc.upv.es/documentation'>documentation section</a>. The report describes the contour integral solvers in SLEPc."],

  ["Mar 21, 2016",
   "SLEPc developers will be attending the forthcoming <a href='https://www.mcs.anl.gov/petsc/meetings/2016/' target=_blank>PETSc User Meeting 2016</a> in Vienna on June 28-30, 2016."],

  ["Nov 3, 2015",
   "New patch release: slepc-3.6.2 contains various fixes, related to the EPSLOBPCG and NEPINTERPOL solvers, among other issues."],

  ["Sep 3, 2015",
   "New patch release: slepc-3.6.1 contains miscellaneous fixes."],

  ["Jun 12, 2015",
   "SLEPc 3.6 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["May 25, 2015",
   "New patch release: slepc-3.5.4 contains miscellaneous fixes, mainly related to the MFN solver and the DS auxiliary class."],

  ["May 19, 2015",
   "A talk and a tutorial on SLEPc will be given at the workshop <a href='https://www.mcs.anl.gov/petsc-20/' target=_blank>Celebrating 20 Years of Computational Science with PETSc</a> at Argonne National Lab on June 15-18, 2015."],

  ["Dec 19, 2014",
   "New patch release: slepc-3.5.3 contains miscellaneous fixes, mainly related to the Fortran stubs and the configuration script."],

  ["Oct 10, 2014",
   "New patch release: slepc-3.5.2 contains miscellaneous fixes, for spectrum slicing, deflation vectors, and others."],

  ["Sep 1, 2014",
   "New patch release: slepc-3.5.1 contains fixes required to install the python wrappers (slepc4py)."],

  ["Jul 29, 2014",
   "SLEPc 3.5 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Mar 24, 2014",
   "New patch release: slepc-3.4.4 contains miscellaneous bug fixes."],

  ["Oct 14, 2013",
   "New patch release: slepc-3.4.3 contains several bug fixes."],

  ["Sep 2, 2013",
   "New patch release: slepc-3.4.2 contains fixes for external packages and Fortran interfaces."],

  ["Jul 31, 2013",
   "New patch release: slepc-3.4.1 contains various fixes for CISS, JD and the SVD for very thin tall matrices."],

  ["Jul 5, 2013",
   "SLEPc 3.4 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["May 1, 2013",
   "New patch release: slepc-3.3-p4 contains miscellaneous fixes."],

  ["Oct 3, 2012",
   "New patch release: slepc-3.3-p3 contains miscellaneous fixes."],

  ["Aug 20, 2012",
   "New patch release: slepc-3.3-p2 fixes the Fortran interfaces and several bugs in Davidson solvers and spectrum slicing."],

  ["Aug 4, 2012",
   "New patch release: slepc-3.3-p1 fixes broken builds with C++."],

  ["Aug 3, 2012",
   "SLEPc 3.3 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Apr 4, 2012",
   "New patch release: slepc-3.2-p5 includes fixes for the EPSJD solver, for external packages, and for the correct generation of shared libraries."],

  ["Feb 14, 2012",
   "New patch release: slepc-3.2-p4 fixes a problem when building with Microsoft compilers."],

  ["Nov 29, 2011",
   "New patch release: slepc-3.2-p3 contains miscellaneous fixes."],

  ["Nov 18, 2011",
   "New patch release: slepc-3.2-p2 contains many fixes for the Davidson solvers and also fixes the Fortran interface for monitors."],

  ["Nov 3, 2011",
   "New patch release: slepc-3.2-p1 contains compilation fixes for C++ and several bugfixes."],

  ["Oct 28, 2011",
   "SLEPc 3.2 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Feb 21, 2011",
   "New patch release: slepc-3.1-p6 contains fixes for the QEP package so that it can be used from Fortran."],

  ["Jan 12, 2011",
   "Added an RSS feed for announcing events and patch releases. Use the &quot;subscribe&quot; button in the front webpage."],

  ["Aug 4, 2010",
   "SLEPc 3.1 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Jun 22, 2010",
   "A SLEPc tutorial will be given as part of the <a href='http://vecpar.fe.up.pt/2010/workshops-ACTS.php' target=_blank>HPC Tools tutorial</a> in the VECPAR conference in Berkeley."],

  ["Jun 3, 2010",
   "We are working on a new SLEPc version that will be compatible with PETSc 3.1. It will be ready in a few weeks. The release will be announced via the <a href='https://slepc.upv.es/contact/mail_list.htm'>SLEPc mailing list</a>."],

  ["Aug 18-21, 2009",
   "A SLEPc tutorial will be given at the <a href='http://acts.nersc.gov/events/Workshop2009/' target=_blank>10th ACTS workshop</a> in Berkeley."],

  ["Feb 3, 2009",
   "SLEPc 3.0.0 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>. A list of <a href='https://slepc.upv.es/download/changes.htm'>changes</a> in this release is available."],

  ["Dec 20, 2008",
   "We are working on a new SLEPc version that will be compatible with PETSc 3.0.0. It will be ready in a few weeks. The release will be announced via the <a href='https://slepc.upv.es/contact/mail_list.htm'>SLEPc mailing list</a>."],

  ["24-27 Jun, 2008",
   "A tutorial on computational tools, including PETSc and SLEPc, is scheduled as part of the <a href='http://vecpar.fe.up.pt/2008' target=_blank>VECPAR 2008</a> conference, to take place in Toulouse (France)."],

  ["16-20 Jul, 2007",
   "A talk devoted to recent developments in SLEPc will be given in the PETSc users minisymposium organized at the <a href='http://www.iciam07.ch' target=_blank>ICIAM 2007</a> conference (Zurich, Switzerland)."],

  ["27-29 Jun, 2007",
   "A SLEPc tutorial (including hands-on session) is included in the programme of <a href='http://www.fep.up.pt/epsa2007' target=_blank>EPSA 2007</a>, to take place in Porto (Portugal)."],

  ["1 Jun, 2007",
   "SLEPc version 2.3.3 has been released. This release includes a new SVD object. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>."],

  ["2 Oct, 2006",
   "SLEPc version 2.3.2 has been released. The distribution file is available at the <a href='https://slepc.upv.es/download'>download page</a>."],

  ["3 Sep, 2006",
   "A new SLEPc version is being prepared and should be ready in a few weeks. The release will be announce via the <a href='https://slepc.upv.es/contact/mail_list.htm'>mailing list</a>. This new version will contain a new Krylov-Schur solver."],

  ["3 Mar, 2006",
   "SLEPc version 2.3.1 is available for download."],

  ["5 Feb, 2006",
   "PETSc 2.3.1 is out. A new SLEPc version will be released in a few weeks. This will be announced via the <a href='https://slepc.upv.es/contact/mail_list.htm'>mailing list</a>."],

  ["28 Sep, 2005",
   "A new SLEPc reference is available, please use this for citation. See the <a href='https://slepc.upv.es/material'>Material</a> section."],

  ["12 Jul, 2005",
   "A tutorial of SLEPc will be given at the 6th ACTS Workshop (August 23-26 in Berkeley). See <a href='http://acts.nersc.gov/events/Workshop2005' target=_blank>more details</a>."],

  ["30 Jun, 2005",
   "A new version of SLEPc is available for download, with new features and compatible with PETSc 2.3.0."],

  ["5 Nov, 2004",
   "A tutorial of SLEPc will be given at the SIAM CSE05 conference (February 12-15 in Orlando, FL), as part of the ACTS morning short course. A talk in session MS48 will be given as well."],

  ["5 Sep, 2004",
   "Hands-on exercises can be found in the <i>Documentation</i> section."],

  ["21 Aug, 2004",
   "SLEPc 2.2.1 has been released. The distribution file is available at the download page."],

  ["5 Jul, 2004",
   "A tutorial of SLEPc will be given at the 5th ACTS Workshop (August 24-27 in Berkeley). See <a href='http://acts.nersc.gov/events/Workshop2004' target=_blank>more details</a>."],

  ["14 Apr, 2004",
   "SLEPc 2.2.0 has been released. The distribution file is available at the download page."]

];
